<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}
/*
Plugin Name: Maishapay Mobile Money
Plugin URI: https://www.maishapay.net/
Description: Extends WooCommerce by Adding the Maishapay Kinshasa Gateway. Social allows MTN Mobile Money, Airtel Money, Visa, Easypay Wallet and MaishapayPay Merchant Account Payment methods.
Version: 1.3
Author: Maishapay
Author URI: https://www.maishapay.online/
*/

add_filter( 'woocommerce_payment_gateways', 'wmm_socialpay_gateway' );
function wmm_socialpay_gateway( $methods ) {
    $methods[] = 'WC_Gateway_Socialpay';
    return $methods;
}

// inserts class gateway
function woocommerce_socialpay_init() {

    if (!class_exists('WC_Gateway_Socialpay')) {

        class WC_Gateway_Socialpay extends WC_Payment_Gateway {
            function __construct() {
                $this->id = "socialpay";
                $this->method_title = __( "Maishapay plugin", 'Maishapay' );
                $this->method_description = __( "Maishapay vous permet de pouvoir effectue de paiement en toute securite", 'Maishapay' );
                $this->title = __( "Maishapay plugin", 'Maishapay' );
                $this->icon = null;
                $this->has_fields = true;
                $this->init_form_fields();
                $this->init_settings();
                foreach ( $this->settings as $setting_key => $value ) {
                    $this->$setting_key = $value;
                }
                if ( is_admin() ) {
                    add_action( 'woocommerce_update_options_payment_gateways_' . $this->id, array( $this, 'process_admin_options' ) );
                }
                add_action('woocommerce_receipt_socialpay', array($this, 'socialpay_receipt_page'));
            }


            public function init_form_fields() {
                $this->form_fields = array(
                    'enabled' => array(
                        'title'		=> __( 'Active / Desactive', 'maishapay' ),
                        'label'		=> __( 'Enable this payment gateway', 'Maishapay' ),
                        'type'		=> 'checkbox',
                        'default'	=> 'no',
                    ),
                    'title' => array(
                        //titre pour MaishaPay
                        'title'		=> __( 'Titre', 'Maishapay' ),
                        'type'		=> 'text',
                        'desc_tip'	=> __( 'Payment title the customer will see during the checkout process.', 'socialpay' ),
                        'default'	=> __( 'Maishapay', 'Maishapay' ),
                        'disable'	=> true,

                    ),
                    'description' => array(
                        'title'		=> __( 'Description', 'Maishapay' ),
                        'type'		=> 'textarea',
                        'desc_tip'	=> __( 'Payment description the customer will see during the checkout process.', 'Maishapay' ),
                        'default'	=> __( 'You will be redirected to socialpay to complete the payment', 'Maishapay' ),
                        'css'		=> 'max-width:350px;'
                    ),
                    'api_key' => array(
                        'title'		=> __( 'Maishapay ID', 'Maishapay' ),
                        'type'		=> 'text',
                        'desc_tip'	=> __( 'Insert votre ID Marchant', 'maishapay'),
                    ),
                    'monnaie' => array(
                        'title'		=> __( 'Devise ', 'Maishapay' ),
                        'type'		=> 'select',
                        'options' => array('USD'=>'Dollars Americain(USD)', 'CDF'=>'Franc congolais(CDF)'),
                        'desc_tip'	=> __( 'Selectionner la devise', 'Maishapay'),
                    )
                    ,
                    'gateway_mode' => array(
                        'title'		=> __( 'Mode ', 'Maishapay Gateway' ),
                        'type'		=> 'select',
                        'options' => array('development'=>'sandbox1', 'production'=>'Maishapay Releance'),
                        'desc_tip'	=> __( 'Gateway Mode', 'Maishapay Gateway'),
                    )


                );
            }

            function process_payment( $order_id ) {
                global $woocommerce;
                $order = new WC_Order( $order_id );

                return array(
                    'result' 	=> 'success',
                    'redirect'	=> add_query_arg('order', $order->id, add_query_arg('key', $order->order_key, get_permalink(woocommerce_get_page_id('pay'))))
                );

            }

            function socialpay_receipt_page( $order ) {


                echo '<p>'.__($this->pay_description, 'woocommerce').'</p>';


                echo $this->generate_socialpay_form( $order );

            }


            function generate_socialpay_form($order_id) {

                global $woocommerce;
                $order = wc_get_order( $order_id );
                $api_login_id = $this->api_key;
                $description = $this->description;
                $currency = $this->monnaie;
                $shop_title = $this->title;
                $items = $order->get_items();

                if ($this->gateway_mode=='development'){

                    $gateway_url = 'https://sandbox1.maishapay.net/checkout/';

                }else{

                    $gateway_url = 'https://www.maishapay.shop/marchand/checkout/';
                }
//items 1

                $i= 0;

                $item_array=array();
                $total = 0;

                foreach($items as  $item){

                    if( $item['type']=='line_item' ){

                        $item_array[$i]['name']=$item['name'];
                        $product = new WC_Product($item['product_id'] );
                        $item_array[$i]['price']=$product->price;
                        $item_array[$i]['qty']=$item['qty'];

                        $total += ($product->price * $item['qty']);

                        if($product->weight){
                            $item_array[$i]['weight']=$product->weight;
                        } else {
                            $item_array[$i]['weight']=0;
                        }
                        if($product->sku){
                            $item_array[$i]['pid']=$product->sku;
                        } else {
                            $item_array[$i]['pid']=$item['product_id'];
                        }
                        $i++;
                    }

                }


//print_r($item_array);

//$item_array = (object) $item_array;

//buyer
                $buyer=new stdClass();
                $buyer->name=$order->billing_first_name;
                $buyer->phonenumber=$order->billing_phone;
                $buyer->phone=$order->billing_phone;
                $buyer->email=$order->billing_email;
                $buyer->address=$order->billing_address_1." ".$order->billing_address_2;
                $buyer->city=$order->billing_city;
                $cart=$item_array;

                $apiOptions = new stdClass();
                $apiOptions->cart=$cart;
                $apiOptions->buyer=$buyer;
                $apiOptions->custOrderId=$order_id;

//print_r($cart);

                $plain_str=json_encode($apiOptions);
// $iv = mcrypt_create_iv(mcrypt_get_iv_size(MCRYPT_RIJNDAEL_256, MCRYPT_MODE_ECB), MCRYPT_RAND);
// $encrypted_string = mcrypt_encrypt(MCRYPT_RIJNDAEL_256, $api_login_id, $plain_str, MCRYPT_MODE_CBC, $iv);
// $apiOptFnl=base64_encode($encrypted_string);
                $apiOptFnl=base64_encode($plain_str);


                $output = "<div id='woocommerce_wmm_wrap'><form action='". $gateway_url."' method='post'>
<input type='hidden' name='apiOptions' value='".urlencode($apiOptFnl)."'/>
<input type='hidden' name='apikey' value='".$api_login_id."'>
<input type='hidden' name='gateway_mode' value='".$api_login_id."'>
<input type='hidden' name='montant' value='".$total."'>
<input type='hidden' name='monnaie' value='".$currency."'>
<input type='hidden' name='payment_description' value='".$description."'>
<input type='hidden' name='logo_url' value='".$shop_title."'>
<input type='hidden' name='page_callback_success' value='".$order->get_checkout_order_received_url()."'>
<input type='hidden' name='page_callback_failure' value='".$order->get_cancel_order_url()."'>
<input type='hidden' name='page_callback_cancel'  value='".$order->get_cancel_order_url()."'> 
<p>Vous serez redirigé vers la page de paiement MaishaPay</p></br>
<input type='submit' value='PAYER MAINTENANT'/>

</form></div>";

                return $output;
            }
        }
    }
}


add_action('woocommerce_init', 'woocommerce_socialpay_init');

add_action('init','wmm_check_woo_data');

/**
 * Auto Complete all WooCommerce orders.
 */
add_action( 'woocommerce_thankyou', 'custom_woocommerce_auto_complete_order' );
function custom_woocommerce_auto_complete_order( $order_id ) { 
    if ( ! $order_id ) {
        return;
    }

    $order = wc_get_order( $order_id );
    $order->update_status( 'completed' );
}

function wmm_check_woo_data(){
    //print_r($_POST);
    if (isset($_POST['transactionId']))
    {
        $txId=sanitize_text_field($_POST['transactionId']);
        $st=sanitize_text_field($_POST['status']);
        if($txId>0 && $st=='success'){
            if (wp_verify_nonce( $_GET['_wpnonce'], 'Maishapay' ) )
            {
                $json_data = json_decode(base64_decode($_POST['options']));
                $order_id =  $txId;
                print_r($_POST);
                if($order_id > 0){
                    $order = new WC_Order( $order_id );
                    $order->update_status('completed');
                    $order->reduce_order_stock();
                    wc()->cart->empty_cart();
                    $order->payment_complete();
                }
            }
        }
    }
}